summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/browser/UserManual.py3
-rw-r--r--src/browser/Welcome.py3
-rw-r--r--src/configuration/Appconfig.py5
-rw-r--r--src/subcircuit/Subcircuit.py7
-rw-r--r--src/subcircuit/convertSub.py10
-rw-r--r--src/subcircuit/newSub.py11
-rw-r--r--src/subcircuit/openSub.py2
7 files changed, 29 insertions, 12 deletions
diff --git a/src/browser/UserManual.py b/src/browser/UserManual.py
index 3bcfbace..6f09190b 100644
--- a/src/browser/UserManual.py
+++ b/src/browser/UserManual.py
@@ -4,7 +4,8 @@ import webbrowser
class UserManual(QtGui.QWidget):
"""
- This class creates Welcome page of eSim.
+ This class opens User-Manual page in new tab of web browser
+ when help button is clicked.
"""
def __init__(self):
diff --git a/src/browser/Welcome.py b/src/browser/Welcome.py
index 2ae8fce1..f9f273df 100644
--- a/src/browser/Welcome.py
+++ b/src/browser/Welcome.py
@@ -2,10 +2,9 @@ from PyQt4 import QtGui, QtCore
class Welcome(QtGui.QWidget):
- """This class creates Welcome page of eSim."""
+ """This class contains content of dock area part of initial esim Window."""
def __init__(self):
- """Sdf."""
QtGui.QWidget.__init__(self)
self.vlayout = QtGui.QVBoxLayout()
diff --git a/src/configuration/Appconfig.py b/src/configuration/Appconfig.py
index 0b34e3fc..38a55595 100644
--- a/src/configuration/Appconfig.py
+++ b/src/configuration/Appconfig.py
@@ -27,6 +27,11 @@ class Appconfig(QtGui.QWidget):
"""
All configuration goes here.
May change in future for code optimization.
+
+ This class also contains function for
+ - Printing error.
+ - Showing warnings.
+ - Dispalying information.
"""
# Home directory
diff --git a/src/subcircuit/Subcircuit.py b/src/subcircuit/Subcircuit.py
index 39c0fe77..d2e7ec5a 100644
--- a/src/subcircuit/Subcircuit.py
+++ b/src/subcircuit/Subcircuit.py
@@ -10,7 +10,12 @@ from subcircuit.convertSub import convertSub
class Subcircuit(QtGui.QWidget):
"""
Creates buttons for New project, Edit existing project and
- Kicad Netlist to Ngspice Netlist converter.
+ Kicad Netlist to Ngspice Netlist converter and link them with the
+ methods defined for it in other files.
+
+ - New Project(NewSub method of newSub).
+ - Open Project(openSub method of openSub).
+ - Kicad to Ngspice convertor(convertSub of convertSub).
"""
def __init__(self, parent=None):
diff --git a/src/subcircuit/newSub.py b/src/subcircuit/newSub.py
index 6b221b4c..678b023d 100644
--- a/src/subcircuit/newSub.py
+++ b/src/subcircuit/newSub.py
@@ -8,10 +8,7 @@ import os
# This class is called when User create new Project.
class NewSub(QtGui.QWidget):
"""
- Contains funstions to check :
- - Name of project should not be blank.
- - Name should not contain space between them.
- - Name does not match with existing project.
+ Contains functions to create directory and validate file names.
"""
def __init__(self):
@@ -21,7 +18,11 @@ class NewSub(QtGui.QWidget):
def createSubcircuit(self, subName):
"""
- This function create Subcircuit related directories and files
+ - This function create workspace for subcircuit.
+ - It also validate file names for Subcircuits:
+ - File name should not contain space.
+ - Name can not be empty.
+ - File name already exists.
"""
self.create_schematic = subName
# Checking if Workspace already exist or not
diff --git a/src/subcircuit/openSub.py b/src/subcircuit/openSub.py
index 4c1394eb..bebd28a1 100644
--- a/src/subcircuit/openSub.py
+++ b/src/subcircuit/openSub.py
@@ -8,7 +8,7 @@ import os
class openSub(QtGui.QWidget):
"""
It opens the existing subcircuit projects that are present in
- Subcircuit Library.
+ Subcircuit directory.
"""
def __init__(self):
diff --git a/src/subcircuit/convertSub.py b/src/subcircuit/convertSub.py
index cce27476..49f5a54f 100644
--- a/src/subcircuit/convertSub.py
+++ b/src/subcircuit/convertSub.py
@@ -9,7 +9,7 @@ import os
class convertSub(QtGui.QWidget):
"""
Contains functions that checks project present for conversion and
also function to convert Kicad to Ngspice.
"""
def __init__(self, dockarea):
@@ -20,7 +20,13 @@ class convertSub(QtGui.QWidget):
def createSub(self):
"""
- This function create command to call kicad to Ngspice converter.
+ This function create command to call KiCad to Ngspice converter.
+ If the netlist is not generated for selected project it will show
+ error **The subcircuit does not contain any Kicad netlist file for
+ conversion.**
+ And if no project is selected for conversion, it again show error
+ message to select a file or create a file.
+
"""
print("Openinig Kicad-to-Ngspice converter from Subcircuit Module")
self.projDir = self.obj_appconfig.current_subcircuit["SubcircuitName"]
@@ -9,7 +9,7 @@ import os
"""
Contains functions that checks project present for conversion and
- also function to convert Kicad to Ngspice.
+ also function to convert Kicad Netlist to Ngspice Netlist.
"""
def __init__(self, dockarea):